Module compose

Module compose 

This module provides utilities for composing multipart mails.

While the Mail type on itself can represent any multipart mail most mails have a certain pattern to their structure, consisting mainly of multipart/mixed for attachments, multipart/alternative for alternative bodies and multipart/related for including embedded resources which can be used in the mail bodies like e.g. a logo.

This module provides the needed utilities to more simply create a Mail instance which represents this kind of mails.

Structs

BodyPart
Parts used to create a mail body (in a multipart mail).
MailParts
Parts which can be used to compose a multipart mail.