pub enum MaybeEncData {
Data(Data),
EncData(EncData),
}
Represents Data which might already have been transfer encoded.
The data is returned normally.
The data is returned in a already transfer encoded variant.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.