Utilities.
Contains everything which doesn’t has a better place to be put in.
Structs
Struct implementing
ConstSwitch with ENABLED = false.Struct implementing
ConstSwitch with ENABLED = true.Traits
Trait to allow const
bool values in generics.Functions
Returns the current data time.
Type Definitions
Type alias for an boxed future which is Send + ’static.